/**
 * Priority queue.
 *
 * Priority queue can insert elements within the complexity of log(N) or remove
 * the largest element in the queue.
 */
export interface IPriorityQueue<T> {
    /**
     * Initialize priority queue with initial elements.
     * @param elements
     */
    init(elements?: ReadonlyArray<T>): void;
    /**
     * Drop a element into the priority queue.
     */
    enqueue(val: T): void;
    /**
     * Popup the top element.
     */
    dequeue(): T | undefined;
    /**
     * Get the top element.
     */
    top(): T | undefined;
    /**
     * Return the number of elements of the priority queue.
     */
    size(): number;
    /**
     * Check if the priority queue is empty.
     */
    isEmpty(): boolean;
    /**
     * Return all of the elements of the priority queue.
     */
    collect(): T[];
}
/**
 * Create a priority queue, implementation based on a max-heap.
 *
 * For example:
 *
 *  createPriorityQueue<number>((x, y) => x - y) // => The top element has a maximum value.
 *  createPriorityQueue<number>((x, y) => y - x) // => The top element has a minimum value.
 *
 * @param cmp   Comparison function, if the result > 0, the element on the left
 *              side of the operator has higher precedence.
 * @returns
 */
export declare function createPriorityQueue<T>(cmp: (x: T, y: T) => -1 | 0 | 1 | number): IPriorityQueue<T>;
